@@ -1,7 +1,6 @@
 import LinearAlgebra.LAPACK: gees!, gges!
 ## Schur and generalized Schur decomposition with reordering
 
-
 # SELECT functions
 """
    enum SCHURORDER lp rp id ed
@@ -33,19 +32,19 @@ function lpselect(wr_::Ptr, wi_::Ptr)::Cint
     wi = unsafe_load(wi_)
     return (wr < SCHUR_CRITERIUM[])
 end
-    
+
 function rpselect(wr_::Ptr, wi_::Ptr)::Cint
     wr = unsafe_load(wr_)
     wi = unsafe_load(wi_)
     return (wr > SCHUR_CRITERIUM[])
 end
-    
+
 function idselect(wr_::Ptr, wi_::Ptr)::Cint
     wr = unsafe_load(wr_)
     wi = unsafe_load(wi_)
     return (wr^2 + wi^2 < SCHUR_CRITERIUM[])
 end
-    
+
 function edselect(wr_::Ptr, wi_::Ptr)::Cint
     wr = unsafe_load(wr_)
     wi = unsafe_load(wi_)
@@ -54,18 +53,18 @@ end
 
 function selectorder2(so::SCHURORDER, criterium)
     global SCHUR_CRITERIUM[] = criterium
-    if so ==  lp
+    if so == lp
         return @cfunction(lpselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}))
-    elseif so ==  rp
+            (Ptr{Cdouble}, Ptr{Cdouble}))
+    elseif so == rp
         return @cfunction(rpselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}))
+            (Ptr{Cdouble}, Ptr{Cdouble}))
     elseif so == id
         return @cfunction(idselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}))
-    elseif so ==  ed
+            (Ptr{Cdouble}, Ptr{Cdouble}))
+    elseif so == ed
         return @cfunction(edselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}))
+            (Ptr{Cdouble}, Ptr{Cdouble}))
     else
         error("Unknown SCHURDORDER keyword: $so")
     end
@@ -76,45 +75,45 @@ end
 function lpselect(αr_::Ptr, αi_::Ptr, β_::Ptr)::Cint
     αr = unsafe_load(αr_)
     αi = unsafe_load(αi_)
-    β  = unsafe_load(β_)
-    return (αr < SCHUR_CRITERIUM[]*β)
+    β = unsafe_load(β_)
+    return (αr < SCHUR_CRITERIUM[] * β)
 end
-    
+
 function rpselect(αr_::Ptr, αi_::Ptr, β_::Ptr)::Cint
     αr = unsafe_load(αr_)
     αi = unsafe_load(αi_)
-    β  = unsafe_load(β_)
-    return (αr >= SCHUR_CRITERIUM[]*β)
+    β = unsafe_load(β_)
+    return (αr >= SCHUR_CRITERIUM[] * β)
 end
 
 function idselect(αr_::Ptr, αi_::Ptr, β_::Ptr)::Cint
     αr = unsafe_load(αr_)
     αi = unsafe_load(αi_)
-    β  = unsafe_load(β_)
-    return (αr^2 + αi^2 < SCHUR_CRITERIUM[]*β^2)
+    β = unsafe_load(β_)
+    return (αr^2 + αi^2 < SCHUR_CRITERIUM[] * β^2)
 end
-    
+
 function edselect(αr_::Ptr, αi_::Ptr, β_::Ptr)::Cint
     αr = unsafe_load(αr_)
     αi = unsafe_load(αi_)
-    β  = unsafe_load(β_)
-    return (αr^2 + αi^2 >= SCHUR_CRITERIUM[]*β^2)
+    β = unsafe_load(β_)
+    return (αr^2 + αi^2 >= SCHUR_CRITERIUM[] * β^2)
 end
 
 function selectorder3(so::SCHURORDER, criterium)
     global SCHUR_CRITERIUM[] = criterium
-    if so ==  lp
+    if so == lp
         return @cfunction(lpselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
-    elseif so ==  rp
+            (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
+    elseif so == rp
         return @cfunction(rpselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
+            (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
     elseif so == id
         return @cfunction(idselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
-    elseif so ==  ed
+            (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
+    elseif so == ed
         return @cfunction(edselect, Cint,
-                          (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
+            (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
     else
         error("Unknown SCHURDORDER keyword: $so")
     end
@@ -132,7 +131,7 @@ end
 function schurselect(f::Function, αr_::Ptr, αi_::Ptr, β_::Ptr)
     αr = unsafe_load(αr_)
     αi = unsafe_load(αi_)
-    β  = unsafe_load(β_)
+    β = unsafe_load(β_)
     return convert(Cint, f(αr, αi, β) ? 1 : 0)
 end
 
@@ -181,7 +180,7 @@ julia> Matrix(t)
  6.2  3.3
 ```
 """
-mutable struct SchurWs{T<:AbstractFloat} <: Workspace
+mutable struct SchurWs{T <: AbstractFloat} <: Workspace
     work::Vector{T}
     wr::Vector{T}
     wi::Vector{T}
@@ -194,28 +193,28 @@ end
 Base.length(ws::SchurWs) = length(ws.wr)
 
 for (gees, elty) in ((:dgees_, :Float64),
-                     (:sgees_, :Float32))
+    (:sgees_, :Float32))
     @eval begin
-        function Base.resize!(ws::SchurWs, A::AbstractMatrix{$elty}; work=true)
+        function Base.resize!(ws::SchurWs, A::AbstractMatrix{$elty}; work = true)
             require_one_based_indexing(A)
             chkstride1(A)
-            n     = checksquare(A)
+            n = checksquare(A)
             resize!(ws.wr, n)
             resize!(ws.wi, n)
             ws.vs = zeros($elty, n, n)
             resize!(ws.bwork, n)
             resize!(ws.eigen_values, n)
             if work
-                info  = Ref{BlasInt}()
+                info = Ref{BlasInt}()
                 ccall((@blasfunc($gees), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
-                       Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{Cvoid}, Ptr{BlasInt}, Clong, Clong),
-                      'V', 'N', C_NULL, n,
-                      A, max(1, stride(A, 2)), C_NULL, ws.wr,
-                      ws.wi, ws.vs, max(size(ws.vs, 1), 1), ws.work,
-                      -1, C_NULL, info, 1, 1)
+                    (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
+                        Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{Cvoid}, Ptr{BlasInt}, Clong, Clong),
+                    'V', 'N', C_NULL, n,
+                    A, max(1, stride(A, 2)), C_NULL, ws.wr,
+                    ws.wi, ws.vs, max(size(ws.vs, 1), 1), ws.work,
+                    -1, C_NULL, info, 1, 1)
 
                 chklapackerror(info[])
 
@@ -223,20 +222,22 @@ for (gees, elty) in ((:dgees_, :Float64),
             end
             return ws
         end
-            
-        SchurWs(A::AbstractMatrix{$elty}) =
-            resize!(SchurWs(Vector{$elty}(undef, 1), $elty[], $elty[], Matrix{$elty}(undef, 0, 0), Ref{BlasInt}(), BlasInt[], Complex{$elty}[]), A) 
+
+        SchurWs(A::AbstractMatrix{$elty}) = resize!(
+            SchurWs(Vector{$elty}(undef, 1), $elty[], $elty[], Matrix{$elty}(undef, 0, 0),
+                Ref{BlasInt}(), BlasInt[], Complex{$elty}[]),
+            A)
 
         function gees!(ws::SchurWs{$elty}, jobvs::AbstractChar,
-                       A::AbstractMatrix{$elty};
-                       select::Union{Nothing,Function,SCHURORDER} = nothing,
-                       criterium::Number = 0.0,
-                       resize=true)
+                A::AbstractMatrix{$elty};
+                select::Union{Nothing, Function, SCHURORDER} = nothing,
+                criterium::Number = 0.0,
+                resize = true)
             require_one_based_indexing(A)
             chkstride1(A)
             n = checksquare(A)
             nws = length(ws)
-            if n != nws  
+            if n != nws
                 if resize
                     resize!(ws, A; work = n > nws)
                 else
@@ -249,37 +250,37 @@ for (gees, elty) in ((:dgees_, :Float64),
             if select isa Function
                 sfunc(wr, wi) = schurselect(select, wr, wi)
                 sel_func = @cfunction($(Expr(:$, :sfunc)), Cint,
-                                      (Ptr{Cdouble}, Ptr{Cdouble}))
+                    (Ptr{Cdouble}, Ptr{Cdouble}))
                 ccall((@blasfunc($gees), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
-                       Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{BlasInt}, Ptr{BlasInt}),
-                      jobvs, 'S', sel_func, n,
-                      A, max(1, stride(A, 2)), ws.sdim, ws.wr,
-                      ws.wi, ws.vs, ldvs, ws.work,
-                      lwork, ws.bwork, info)
+                    (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
+                        Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{BlasInt}, Ptr{BlasInt}),
+                    jobvs, 'S', sel_func, n,
+                    A, max(1, stride(A, 2)), ws.sdim, ws.wr,
+                    ws.wi, ws.vs, ldvs, ws.work,
+                    lwork, ws.bwork, info)
             elseif select isa SCHURORDER
                 sel_func = selectorder2(select, criterium)
                 ccall((@blasfunc($gees), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
-                       Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{BlasInt}, Ptr{BlasInt}),
-                      jobvs, 'S', sel_func, n,
-                      A, max(1, stride(A, 2)), ws.sdim, ws.wr,
-                      ws.wi, ws.vs, ldvs, ws.work,
-                      lwork, ws.bwork, info)
+                    (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
+                        Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{BlasInt}, Ptr{BlasInt}),
+                    jobvs, 'S', sel_func, n,
+                    A, max(1, stride(A, 2)), ws.sdim, ws.wr,
+                    ws.wi, ws.vs, ldvs, ws.work,
+                    lwork, ws.bwork, info)
             else
                 ccall((@blasfunc($gees), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
-                       Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{Cvoid}, Ptr{BlasInt}),
-                      jobvs, 'N', C_NULL, n,
-                      A, max(1, stride(A, 2)), Ref{BlasInt}(), ws.wr,
-                      ws.wi, ws.vs, ldvs, ws.work,
-                      lwork, C_NULL, info)
+                    (Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid}, Ref{BlasInt},
+                        Ptr{$elty}, Ref{BlasInt}, Ptr{BlasInt}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{Cvoid}, Ptr{BlasInt}),
+                    jobvs, 'N', C_NULL, n,
+                    A, max(1, stride(A, 2)), Ref{BlasInt}(), ws.wr,
+                    ws.wi, ws.vs, ldvs, ws.work,
+                    lwork, C_NULL, info)
             end
 
             chklapackerror(info[])
@@ -396,11 +397,11 @@ Base.length(ws::GeneralizedSchurWs) = length(ws.αr)
 
 # look into matlab function
 for (gges, elty) in ((:dgges_, :Float64),
-                     (:sgges_, :Float32))
+    (:sgges_, :Float32))
     @eval begin
-        function Base.resize!(ws::GeneralizedSchurWs, A::AbstractMatrix{$elty}; work=true)
+        function Base.resize!(ws::GeneralizedSchurWs, A::AbstractMatrix{$elty}; work = true)
             chkstride1(A)
-            n     = checksquare(A)
+            n = checksquare(A)
             resize!(ws.αr, n)
             resize!(ws.αi, n)
             resize!(ws.β, n)
@@ -409,35 +410,38 @@ for (gges, elty) in ((:dgges_, :Float64),
             ws.vsl = zeros($elty, n, n)
             ws.vsr = zeros($elty, n, n)
             if work
-                info  = Ref{BlasInt}()
+                info = Ref{BlasInt}()
                 ccall((@blasfunc($gges), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{Cvoid}, Ptr{$elty}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
-                       Ref{BlasInt}, Clong, Clong, Clong),
-                      'V', 'V', 'N', C_NULL,
-                      n, A, max(1, stride(A, 2)), A,
-                      max(1, stride(A, 2)), C_NULL, ws.αr, ws.αi,
-                      ws.β, ws.vsl, n, ws.vsr,
-                      n, ws.work, -1, C_NULL,
-                      info, 1, 1, 1)
+                    (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{Cvoid}, Ptr{$elty}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
+                        Ref{BlasInt}, Clong, Clong, Clong),
+                    'V', 'V', 'N', C_NULL,
+                    n, A, max(1, stride(A, 2)), A,
+                    max(1, stride(A, 2)), C_NULL, ws.αr, ws.αi,
+                    ws.β, ws.vsl, n, ws.vsr,
+                    n, ws.work, -1, C_NULL,
+                    info, 1, 1, 1)
 
                 chklapackerror(info[])
                 resize!(ws.work, BlasInt(real(ws.work[1])))
             end
             return ws
         end
-        GeneralizedSchurWs(A::AbstractMatrix{$elty}) = 
-            resize!(GeneralizedSchurWs(Vector{$elty}(undef, 1), $elty[], $elty[], $elty[], Matrix{$elty}(undef, 0, 0), Matrix{$elty}(undef, 0, 0), Ref{BlasInt}(), BlasInt[], Complex{$elty}[]), A)
+        GeneralizedSchurWs(A::AbstractMatrix{$elty}) = resize!(
+            GeneralizedSchurWs(Vector{$elty}(undef, 1), $elty[], $elty[], $elty[],
+                Matrix{$elty}(undef, 0, 0), Matrix{$elty}(undef, 0, 0),
+                Ref{BlasInt}(), BlasInt[], Complex{$elty}[]),
+            A)
 
         function gges!(ws::GeneralizedSchurWs, jobvsl::AbstractChar,
-                       jobvsr::AbstractChar,
-                       A::AbstractMatrix{$elty}, B::AbstractMatrix{$elty};
-                       select::Union{Nothing,Function,SCHURORDER} = nothing,
-                       criterium::Number = 0, 
-                       resize=true)
+                jobvsr::AbstractChar,
+                A::AbstractMatrix{$elty}, B::AbstractMatrix{$elty};
+                select::Union{Nothing, Function, SCHURORDER} = nothing,
+                criterium::Number = 0,
+                resize = true)
             chkstride1(A, B)
             n = checksquare(A)
             m = checksquare(B)
@@ -459,53 +463,53 @@ for (gges, elty) in ((:dgges_, :Float64),
             if select isa Function
                 sfunc(αr, αi, β) = schurselect(select, αr, αi, β)
                 sel_func = @cfunction($(Expr(:$, :sfunc)), Cint,
-                                      (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
+                    (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
                 ccall((@blasfunc($gges), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
-                       Ref{BlasInt}, Clong, Clong, Clong),
-                      jobvsl, jobvsr, 'S', sel_func,
-                      n, A, max(1, stride(A, 2)), B,
-                      max(1, stride(B, 2)), ws.sdim, ws.αr, ws.αi,
-                      ws.β, ws.vsl, ldvsl, ws.vsr,
-                      ldvsr, ws.work, length(ws.work), ws.bwork,
-                      info, 1, 1, 1)
+                    (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
+                        Ref{BlasInt}, Clong, Clong, Clong),
+                    jobvsl, jobvsr, 'S', sel_func,
+                    n, A, max(1, stride(A, 2)), B,
+                    max(1, stride(B, 2)), ws.sdim, ws.αr, ws.αi,
+                    ws.β, ws.vsl, ldvsl, ws.vsr,
+                    ldvsr, ws.work, length(ws.work), ws.bwork,
+                    info, 1, 1, 1)
             elseif select isa SCHURORDER
                 sel_func = selectorder3(select, criterium)
                 ccall((@blasfunc($gges), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
-                       Ref{BlasInt}, Clong, Clong, Clong),
-                      jobvsl, jobvsr, 'S', sel_func,
-                      n, A, max(1, stride(A, 2)), B,
-                      max(1, stride(B, 2)), ws.sdim, ws.αr, ws.αi,
-                      ws.β, ws.vsl, ldvsl, ws.vsr,
-                      ldvsr, ws.work, length(ws.work), ws.bwork,
-                      info, 1, 1, 1)
+                    (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
+                        Ref{BlasInt}, Clong, Clong, Clong),
+                    jobvsl, jobvsr, 'S', sel_func,
+                    n, A, max(1, stride(A, 2)), B,
+                    max(1, stride(B, 2)), ws.sdim, ws.αr, ws.αi,
+                    ws.β, ws.vsl, ldvsl, ws.vsr,
+                    ldvsr, ws.work, length(ws.work), ws.bwork,
+                    info, 1, 1, 1)
             else
                 ccall((@blasfunc($gges), liblapack), Cvoid,
-                      (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
-                       Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
-                       Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
-                       Ref{BlasInt}, Clong, Clong, Clong),
-                      jobvsl, jobvsr, 'N', C_NULL,
-                      n, A, max(1, stride(A, 2)), B,
-                      max(1, stride(B, 2)), Ref{BlasInt}(), ws.αr, ws.αi,
-                      ws.β, ws.vsl, ldvsl, ws.vsr,
-                      ldvsr, ws.work, length(ws.work), C_NULL,
-                      info, 1, 1, 1)
+                    (Ref{UInt8}, Ref{UInt8}, Ref{UInt8}, Ptr{Cvoid},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ref{BlasInt}, Ptr{$elty}, Ptr{$elty},
+                        Ptr{$elty}, Ptr{$elty}, Ref{BlasInt}, Ptr{$elty},
+                        Ref{BlasInt}, Ptr{$elty}, Ref{BlasInt}, Ptr{Cvoid},
+                        Ref{BlasInt}, Clong, Clong, Clong),
+                    jobvsl, jobvsr, 'N', C_NULL,
+                    n, A, max(1, stride(A, 2)), B,
+                    max(1, stride(B, 2)), Ref{BlasInt}(), ws.αr, ws.αi,
+                    ws.β, ws.vsl, ldvsl, ws.vsr,
+                    ldvsr, ws.work, length(ws.work), C_NULL,
+                    info, 1, 1, 1)
             end
             chklapackerror(info[])
             @inbounds for i in axes(A, 1)
-                ws.eigen_values[i] = complex(ws.αr[i], ws.αi[i])/ws.β[i]
+                ws.eigen_values[i] = complex(ws.αr[i], ws.αi[i]) / ws.β[i]
             end
             return A, B, complex.(ws.αr, ws.αi), ws.β, ws.vsl, ws.vsr
         end
@@ -538,5 +542,6 @@ The left Schur vectors are returned in `ws.vsl` and the right Schur vectors are
 
 See also FastLapackInterface.SCHURODER
 """
-gges!(ws::GeneralizedSchurWs, jobvsl::AbstractChar, jobvsr::AbstractChar, A::AbstractMatrix,
-      B::AbstractMatrix; kwargs...)
+gges!(
+    ws::GeneralizedSchurWs, jobvsl::AbstractChar, jobvsr::AbstractChar, A::AbstractMatrix,
+    B::AbstractMatrix; kwargs...)
